#ifndef HARKIO_ANALYZEERROR_HPP_
#define HARKIO_ANALYZEERROR_HPP_

#include <stdexcept>
#include <string>

/** @file AnalyzeError.hpp
 * @brief AnalyzeError exception class definition.
 */

namespace harkio2
{

/** @brief An analyze error.
 * A exception class which represents that an error occured while analyzing.
 */
class AnalyzeError : public std::runtime_error
{
public:
    explicit AnalyzeError(const std::string& arg)
        : std::runtime_error(arg), knownLine(false), line_(-1)
    {}

    AnalyzeError(const std::string& arg, int line)
        : std::runtime_error(arg), knownLine(line >= 0), line_(line)
    {}

    virtual int line() const throw() { return line_; }

private:
    /// @brief Whether the erroneous line was specified by constructor.
    bool knownLine;
    /// @brief The line number of the errorneous line.
    int line_;
};

}

#endif // HARKIO_ANALYZEERROR_HPP_

