#ifndef HARKIO_HARKCONFIG_FILE_HPP_
#define HARKIO_HARKCONFIG_FILE_HPP_

#include <harkio2/defineitem.hpp>
#include <vector>
#include <glibmm/ustring.h>

/** @file File.hpp
 * @brief File class and subclasses definitions.
 */

namespace harkio2
{
namespace harkconfig
{

/** @brief A sound source file.
 * This class specifies information about a sound source file.
 */
class File
{
public:
    virtual ~File() {}

    /** @brief Returns the data structure version.
     * Returns the version which this instance actually represents.
     * @return The version of this structure.
     */
    virtual unsigned int GetVersion() const = 0;
};

/** @brief A sound source file information version 1.
 */
class File1 : public File
{
public:
    /** @brief Returns the source version.
     * @return The version which this class represents.
     */
    virtual unsigned int GetVersion() const { return 1; }

    /// @brief The file name of the sound source file.
    DEFINE_ITEM(name, Glib::ustring, Name, const Glib::ustring&)

    /// @brief Micarray indices this file is containing.
    DEFINE_ITEM(micIndices, std::vector<unsigned int>, MicIndices, const std::vector<unsigned int>&)

    /// @brief A comment.
    DEFINE_ITEM(comment, Glib::ustring, Comment, const Glib::ustring&)

};

}
}

#endif // HARKIO_HARKCONFIG_FILE_HPP_

