#define BOOST_TEST_MODULE testcase for TSPListFile class
#define BOOST_TEST_DYN_LINK
#include "common.hpp"

#include <boost/test/unit_test.hpp>

#include <vector>
#include <boost/shared_ptr.hpp>
#include <harkio2/harkconfig/HarkConfigFile.hpp>
#include <harkio2/harkconfig/ImpulseResponseListFile.hpp>
#include <harkio2/harkconfig/TSPListFile.hpp>

using namespace harkio2;
using namespace harkio2::harkconfig;
using namespace boost;
using namespace std;

typedef boost::shared_ptr<HarkConfigFile> hcptr;
typedef boost::shared_ptr<TSPListFile> tspptr;
typedef boost::shared_ptr<TSPListFile1_0> tsp1_0ptr;

BOOST_AUTO_TEST_CASE(constructor_test)
{
    hcptr hc(new TSPListFile1_0());

    BOOST_CHECK_EQUAL(hc->GetId() , "TSPListFile");
    BOOST_CHECK(hc->GetVersion() == Version(1, 0));

    BOOST_CHECK(dynamic_pointer_cast<ImpulseResponseListFile>(hc) == 0);
    BOOST_CHECK(dynamic_pointer_cast<TSPListFile>(hc) != 0);
    tspptr tsp = dynamic_pointer_cast<TSPListFile>(hc);

    BOOST_CHECK(dynamic_pointer_cast<TSPListFile1_0>(tsp) != 0);
}

BOOST_AUTO_TEST_CASE(accessor_test)
{
    tsp1_0ptr tsp(new TSPListFile1_0());

    BOOST_CHECK_THROW(tsp->GetSources(), NotInitialized);
    vector<Source1> sources;
    sources.push_back(Source1());
    tsp->SetSources(sources);
    BOOST_CHECK(tsp->GetSources().size() == 1);

    BOOST_CHECK_THROW(tsp->GetSynchronousAverage(), NotInitialized);
    tsp->SetSynchronousAverage(10);
    BOOST_CHECK(tsp->GetSynchronousAverage() == 10);

    BOOST_CHECK_THROW(tsp->GetOriginalImpulseFltFile(), NotInitialized);
    tsp->SetOriginalImpulseFltFile("hoge.dat");
    BOOST_CHECK(tsp->GetOriginalImpulseFltFile() == "hoge.dat");

    BOOST_CHECK_THROW(tsp->GetTSPOffset(), NotInitialized);
    tsp->SetTSPOffset(20);
    BOOST_CHECK(tsp->GetTSPOffset() == 20);

    BOOST_CHECK_THROW(tsp->GetSignalMax(), NotInitialized);
    tsp->SetSignalMax(30);
    BOOST_CHECK(tsp->GetSignalMax() == 30);

    BOOST_CHECK_THROW(tsp->GetChannelList(), NotInitialized);
    vector<int> channelList;
    channelList.push_back(3);
    tsp->SetChannelList(channelList);
    BOOST_CHECK(tsp->GetChannelList().size() == 1);
    BOOST_CHECK(tsp->GetChannelList().back() == 3);

}

